@@ -78,7 +78,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0181
+version 0.0182
 
 =head1 DESCRIPTION
 
@@ -202,20 +202,16 @@ Export function, that won't be available in the source class
     package My::Lib;
     use Evo '-Export *; -Loaded';
 
-    BEGIN {
-      export_gen foo => sub ($class) {
-        say "$class requested me";
-        sub {"hello, $class"};
-      };
-    }
+    export_gen foo => sub ($class) {
+      say "$class requested me";
+      sub {"hello, $class"};
+    };
   };
 
 
-  use My::Lib '*';
+  My::Lib->import('*');
   foo();
 
-I<L<Evo::Loaded> and C<BEGIN> are for example only, don't needed in the real code>
-
 Very powefull and most exciting feature. C<Evo::Export> exports generators, that produces subroutines. Consider it as a 3nd dimension in 3d programming
 
 Implementation garanties that one module will get the same (cashed) generated unit (if it'l import twice or import from module that reimport the same thing), but different module will get another one
